@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: toolbar.h 3057 2006-11-06 17:14:37Z roms $ */
+/* $Id: toolbar.h 366 2004-03-22 18:04:07Z roms $ */
 
-/*  TiLP - Tilp Is a Linking Program
- *  Copyright (C) 1999-2006  Romain Lievin
+/*  tilp - Ti Linking Program
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #ifndef GTOOLBAR_H
 #define GTOOLBAR_H
 
+void toolbar_set_images(void);
 void toolbar_refresh_buttons(void);
-void toolbar_set_button(int sr);
 
 #endif
